function ydif = dat_dif(yin, dx)
%DAT_DIF Differentiation der Datenmatrix yin durch
% spaltenweise Anwendung von SAVITZKY-GOLAY
% Eingabe:	yin = [y1(x) y2(x) ....] Datenmatrix
%		dx    : Schrittweite (quidistante Spektren)
% Ausgabe:	ydif  : differenzierte Datenmatrix
% Externa:	sg_dif: Funktion zur Differentiation nach SAVITZKY-GOLAY
% letzte nderung 07.02.1996	S. Baunack

% Vereinbarungen und Initialisierungen
dif_ok = 0;
[ndat, nkurv] = size(yin);
dx =abs(dx);	% Schrittweite > 0 fr XPS	
yint = yin;
nzyk = 0;

while 1,	% Differentiationsparameter erfragen
	grad = 1;
	disp(sprintf('\n   ----- Differentiation nach SAVITZKY-GOLAY mit gleitender Randpunktbehandlung -----\n'))
	disp(sprintf('   Differentiation durch Polynom vom Grad M durch n Punkte (n ungerade).'))
	disp(sprintf('   Intervallbreite > Grad des Polynoms.'));
	while grad <= 1,	
		grad = input('   Grad M des Polynoms (>1): ');
	end

	disp(sprintf('   Intervallbreite:\tn - ungerade (> %d)\n\t\t\t0 - Abbruch', grad))
	ndif = input ('   Auswahl: ');
	cdif = (ndif - 1) / 2;
	ctest = cdif - round(cdif);
	if ((ctest == 0) & (ndif > grad)),
		dif_ok = 1;
		break
	elseif ndif == 0,
		break
	end
end
	
if dif_ok == 1,
	disp(sprintf('\n   %d-Punkte-Differentiation nach SAVITZKY-GOLAY mit Polynom %d. Grades.', ndif, grad))
	nzyk = input('   Ordnung der Ableitung: ');
	if nzyk > 1,
		test = janein(' Soll wirklich hhere Ableitung berechnet werden?',2);
		if test == 1,
		else
			disp ('     1. Ableitung ')
			nzyk = 1;	
		end
	else
	end

	disp('')
	disp ('   Rechnung luft. ')

	% Differentiation
	for i = 1:nkurv
		ydif(:,i) = sg_difn(yin(:,i), grad, ndif, nzyk, dx);
	end
end

% Darstellung der bearbeiteten Daten
figure(1)
plot(ydif)
xlabel ('Datenpunkt')
ylabel ('y(x)')
s1 = sprintf('%d. Ableitung (%d-Punkte nach SAVITZKY-GOLAY mit Polynom %d. Grades)', nzyk, ndif, grad);
title (s1);
pos=[0,-0.1];
texth=text('Units','normalized','Position',pos,'String','<weiter>');

sctest = janein('Ableitung akzeptieren?',1);
if sctest == 1,
	s1 = ['Spektren differenziert'];
elseif sctest  == 0,
	s1 = ['Bearbeitung abgebrochen'];
	ydif = yin; 
end

% Darstellung der Ausgabedaten
figure(1)
plot(ydif)
xlabel ('Datenpunkt')
ylabel ('y(x)')
title (s1);
pos=[0,-0.1];
texth=text('Units','normalized','Position',pos,'String','<weiter>');