function cf = difc(grad, n)
%DIFC berechnet die Koeffizienten fr Differentiation nach SAVITZKY-GOLAY
%     durch Polynom vom Grad grad durch n Punkte
% Eingabe: grad: Grad des Polynoms
%          n   : Differentiationsintervall (ungerade)
% Ausgabe: cf  : Vektor der Filterkoeffiziienten
%
% Berechnung der Filterkoeffizienten fr SAVITZKY-GOLAY Differentiation mit Filter abgeleitet aus:
% W. Gander, J. HREBICEK: Solving Problems in Scientific Computing using Maple and Matlab,
% 2nd Ed. (Chapter 9), Springer Heidelberg 1995
%
% letzte nderung 10.02.2000	S. Baunack

% Matrix A
A = ones(n, grad+1);
nl = (n - 1) /2;
nr = nl;
for j = grad:-1:1,
	A(:, j) = [-nl:nr]' .* A(:, j+1);
end

% Filterkoeffizienten cf
[Q, R] = qr(A);
cf = Q(:, grad) / R(grad, grad);