function ysmo = smo_sg(yin)
%SMO_SG Glttung der Datenmatrix yin durch Anwendung von SAVITZKY-GOLAY auf die Spektren
% Eingabe:	yin = [y1(x) y2(x) ....] Datenmatrix
% Ausgabe:	ysmo  : geglttete Datenmatrix
% Externa:	sg_smon: Funktion zur Glttung nach SAVITZKY-GOLAY
%
% letzte nderung 10.02.1996	S. Baunack

% Vereinbarungen und Initialisierungen
smo_ok = 0;
grad = 1;
[ndat, nkurv] = size(yin);
nzyk = 0;

while 1,	% Glttungsparameter erfragen
	grad = 1;
	disp(sprintf('\n   ----- Glttung nach SAVITZKY-GOLAY mit gleitender Randpunktbehandlung -----\n'))
	disp(sprintf('   Glttung durch Polynom vom Grad M durch n Punkte (n ungerade).'))
	disp(sprintf('   Intervallbreite > Grad des Polynoms.'));
	while grad <= 1,	
		grad = input('   Grad M des Polynoms (>1): ');
	end

	disp(sprintf('   Intervallbreite:\tn - ungerade (> %d)\n\t\t\t0 - Abbruch', grad))
	nsmo = input ('   Auswahl: ');
	csmo = (nsmo - 1) / 2;
	ctest = csmo - round(csmo);
	if ((ctest == 0) & (nsmo > grad) ),
		smo_ok = 1;
		break
	elseif nsmo == 0,
		break
	end
end

if smo_ok == 1, % Glttung
	disp(sprintf('   %d-Punkte-Glttung nach SAVITZKY-GOLAY mit Polynom %d. Grades.', nsmo, grad));
	while nzyk <= 0,
		nzyk = input('   Zahl der Zyklen: ');
	end
	disp('')
	disp ('   Rechnung luft. ')

	% Glttung
	for i = 1:nkurv
		ysmo(:,i) = sg_smon(yin(:,i), grad, nsmo, nzyk);
	end
	s1 = sprintf('%d-fache %d-Punkte-Glttung nach SAVITZKY-GOLAY mit Polynom %d. Grades', nzyk, nsmo, grad);

	% Darstellung der bearbeiteten Daten
	figure(1)
	plot(ysmo)
	xlabel ('Datenpunkt')
	ylabel ('y(x)')
	title (s1);
	pos=[0,-0.1];
	texth=text('Units','normalized','Position',pos,'String','<weiter>');

	smtest = janein('Glttung akzeptieren?',1);
	if smtest == 0,
		s1 = ['Glttung verworfen'];
	ysmo = yin; 
	end
else
	ysmo = yin;
	s1 = sprintf('Bearbeitung abgebrochen');
end

% Darstellung der Ausgabedaten
figure(1)
plot(ysmo)
xlabel ('Datenpunkt')
ylabel ('y(x)')
title (s1);
pos=[0,-0.1];
texth=text('Units','normalized','Position',pos,'String','<weiter>');