function cf = smoc(grad, n)
%SMOC berechnet die Koeffizienten fr Glttung nach SAVITZKY-GOLAY
%     durch Polynom vom Grad grad durch n Punkte
% Syntax cf = smoc(grad, n)
% Eingabe: grad: Grad des Polynoms
%          n   : Glttungsintervall (ungerade)
% Ausgabe: cf  : Vektor der Filterkoeffiziienten
%
% Berechnung der Filterkoeffizienten fr SAVITZKY-GOLAY Glttung mit Filter entnommen aus:
% W. Gander, J. HREBICEK: Solving Problems in Scientific Computing using Maple and Matlab,
% 2nd Ed. (Chapter 9), Springer Heidelberg 1995
%
% letzte nderung 11.02.2000	S. Baunack

% Matrix A
A = ones (n, grad+1);
nl = (n - 1) /2;
nr = nl;
for j = grad:-1:1,
	A (:, j) = [-nl:nr]' .* A (:, j+1);
end

% Filterkoeffizienten cf
[Q, R] = qr (A);
cf = Q (:, grad+1) / R (grad+1, grad+1);